@@ -1,18 +1,13 @@
 # FILE: src/circuit_synth/core/circuit.py
 
-import json
-import os
+import inspect
 import re
-import tempfile
 from pathlib import Path  # Import Path
 from typing import Any, Dict, List, Optional
 
 from ._logger import context_logger
-from .exception import CircuitSynthError, ValidationError
-from .json_encoder import CircuitSynthJSONEncoder
+from .exception import ValidationError
 from .net import Net
-
-# Import the exporter function
 from .netlist_exporter import NetlistExporter
 from .reference_manager import ReferenceManager
 
@@ -32,6 +27,8 @@ class Circuit:
         self._component_list = []
         self._reference_manager = ReferenceManager()
         self._annotations = []  # Store TextProperty, TextBox, etc.
+        self._ref_mapping = {}  # Track prefix -> final ref mappings for source rewriting
+        self._circuit_func = None  # Store reference to the @circuit decorated function
 
     def validate_reference(self, ref: str) -> bool:
         """Check if reference is available in this circuit's scope"""
@@ -196,6 +193,12 @@ class Circuit:
                 newly_assigned[final_ref] = comp
                 to_remove.append(key)
 
+                # Capture ref mapping for source rewriting
+                # Use list to track multiple components with same prefix
+                if prefix not in self._ref_mapping:
+                    self._ref_mapping[prefix] = []
+                self._ref_mapping[prefix].append(final_ref)
+
                 context_logger.debug(
                     "Assigned final reference for prefix",
                     component="CIRCUIT",
@@ -225,6 +228,127 @@ class Circuit:
         for sc in self._subcircuits:
             sc.finalize_references()
 
+    def _get_source_file(self) -> Optional[Path]:
+        """Get the source file path for this circuit's function.
+
+        Uses Python's inspect module to find where the @circuit decorated
+        function was defined.
+
+        Returns:
+            Path to source file, or None if not available (REPL, exec, frozen app)
+        """
+        if not self._circuit_func:
+            context_logger.debug(
+                "No circuit function reference available",
+                component="CIRCUIT",
+                circuit_name=self.name
+            )
+            return None
+
+        try:
+            source_file = inspect.getfile(self._circuit_func)
+
+            # Check for special cases where source isn't available
+            if source_file == '<stdin>' or source_file == '<string>':
+                context_logger.warning(
+                    "Circuit defined in REPL/exec environment, source file not available",
+                    component="CIRCUIT",
+                    circuit_name=self.name
+                )
+                return None
+
+            # Check for frozen applications (PyInstaller, etc)
+            if getattr(inspect.sys, 'frozen', False):
+                context_logger.warning(
+                    "Running in frozen application, source file not available",
+                    component="CIRCUIT",
+                    circuit_name=self.name
+                )
+                return None
+
+            path = Path(source_file).resolve()
+
+            if not path.exists():
+                context_logger.warning(
+                    "Source file no longer exists",
+                    component="CIRCUIT",
+                    circuit_name=self.name,
+                    source_file=str(path)
+                )
+                return None
+
+            return path
+
+        except (TypeError, OSError) as e:
+            context_logger.warning(
+                "Could not determine source file",
+                component="CIRCUIT",
+                circuit_name=self.name,
+                error=str(e)
+            )
+            return None
+
+    def _update_source_refs(self, source_file: Path) -> bool:
+        """Update component refs in the source file.
+
+        Uses SourceRefRewriter to atomically update ref values in the
+        Python source file, preserving formatting and encoding.
+
+        Args:
+            source_file: Path to the Python source file to update
+
+        Returns:
+            True if update succeeded, False if skipped or failed
+        """
+        if not self._ref_mapping:
+            context_logger.debug(
+                "No ref mapping to apply",
+                component="CIRCUIT",
+                circuit_name=self.name
+            )
+            return False
+
+        try:
+            from .source_ref_rewriter import SourceRefRewriter
+
+            context_logger.info(
+                "Updating source file with finalized refs",
+                component="CIRCUIT",
+                circuit_name=self.name,
+                source_file=str(source_file),
+                ref_mapping=self._ref_mapping
+            )
+
+            rewriter = SourceRefRewriter(source_file, self._ref_mapping)
+            success = rewriter.update()
+
+            if success:
+                context_logger.info(
+                    "Source file updated successfully",
+                    component="CIRCUIT",
+                    circuit_name=self.name,
+                    refs_updated=len(self._ref_mapping)
+                )
+            else:
+                context_logger.debug(
+                    "Source file unchanged (no modifications needed)",
+                    component="CIRCUIT",
+                    circuit_name=self.name
+                )
+
+            return success
+
+        except Exception as e:
+            context_logger.error(
+                "Failed to update source file",
+                component="CIRCUIT",
+                circuit_name=self.name,
+                source_file=str(source_file),
+                error=str(e)
+            )
+            # Don't raise - source rewriting failure shouldn't break project generation
+            return False
+
     def _add_docstring_annotation(self):
         """Add a TextBox annotation with the circuit's docstring."""
         # Check if docstring annotation already exists to prevent duplicates
@@ -305,6 +429,41 @@ class Circuit:
             circuit_name=self.name,
         )
 
+    def add_image(self, image_path: str, position: tuple, scale: float = 1.0):
+        """
+        Add an embedded image to the schematic.
+
+        Images are embedded as base64-encoded data in the KiCad schematic file.
+        The image file is read when the schematic is generated, so it only needs
+        to exist at generation time.
+
+        Args:
+            image_path: Path to image file (PNG, JPG, etc.)
+            position: Tuple of (x, y) position in mm
+            scale: Scale factor (1.0 = original size, 2.0 = 2x larger, etc.)
+
+        Returns:
+            Image: The created Image annotation object
+
+        Example:
+            >>> circuit.add_image("logo.png", position=(100, 50), scale=2.0)
+        """
+        from .annotations import Image
+
+        img = Image(image_path=image_path, position=position, scale=scale)
+        self.add_annotation(img)
+
+        context_logger.debug(
+            "Added image to circuit",
+            component="CIRCUIT",
+            image_path=image_path,
+            position=position,
+            scale=scale,
+            circuit_name=self.name,
+        )
+
+        return img
+
     def to_dict(self) -> Dict[str, Any]:
         """
         Return a hierarchical dictionary representation of this circuit,
@@ -348,8 +507,6 @@ class Circuit:
         """
         import json
 
-        from .netlist_exporter import NetlistExporter
-
         # Collect all components and nets from this circuit and all subcircuits
         all_components = {}  # ref -> component_dict
         all_nets = {}  # net_name -> [connections]
@@ -455,13 +612,14 @@ class Circuit:
         placement_algorithm: str = "connection_centric",
         draw_bounding_boxes: bool = False,
         generate_ratsnest: bool = True,
-    ) -> None:
+        update_source_refs: Optional[bool] = None,
+    ) -> Dict[str, Any]:
         """
         Generate a complete KiCad project (schematic + PCB) from this circuit.
 
         This method provides a simplified API that handles all the boilerplate setup
         required for KiCad project generation, creating the project directory and
-        generating KiCad files directly without intermediate JSON files.
+        generating KiCad files with an automatic JSON netlist in the project directory.
 
         Args:
             project_name: Name of the KiCad project and directory to create
@@ -470,17 +628,53 @@ class Circuit:
             placement_algorithm: Component placement algorithm to use (default: "connection_centric")
             draw_bounding_boxes: Whether to draw visual bounding boxes around components (default: False)
             generate_ratsnest: Whether to generate ratsnest connections in PCB (default: True)
+            update_source_refs: Whether to update source file with finalized refs.
+                               None (default): Auto-update unless force_regenerate=True
+                               True: Always update source file
+                               False: Never update source file
+
+        Returns:
+            dict: Result dictionary containing:
+                - success (bool): Whether generation succeeded
+                - json_path (Path): Path to the canonical JSON netlist
+                - project_path (Path): Path to the KiCad project directory
+                - error (str, optional): Error message if generation failed
 
         Example:
             >>> circuit = esp32s3_simple()
-            >>> circuit.generate_kicad_project("esp32s3_simple")
+            >>> result = circuit.generate_kicad_project("esp32s3_simple")
+            >>> print(f"JSON netlist: {result['json_path']}")
+            >>> print(f"KiCad project: {result['project_path']}")
         """
         try:
-            from ..kicad.config import KiCadConfig, get_recommended_generator
-            
+            from ..kicad.config import get_recommended_generator
+            from .. import print_version_info
+
+            # Print version information for debugging
+            print_version_info()
+            print()  # Blank line after version info
+
             # Finalize references before generation
             self.finalize_references()
 
+            # Determine if we should update source file
+            should_update_source = update_source_refs
+            if should_update_source is None:
+                # Auto mode: update unless force_regenerate
+                should_update_source = not force_regenerate
+
+            # Update source file with finalized refs if enabled
+            if should_update_source:
+                source_file = self._get_source_file()
+                if source_file:
+                    self._update_source_refs(source_file)
+                else:
+                    context_logger.debug(
+                        "Source file not available, skipping ref update",
+                        component="CIRCUIT",
+                        circuit_name=self.name
+                    )
+
             # Create output directory with the project name
             output_path = Path(project_name).resolve()
             output_path.mkdir(parents=True, exist_ok=True)
@@ -500,38 +694,30 @@ class Circuit:
 
             context_logger.info("Using hybrid approach: legacy positioning + modern kicad-sch-api file writing", component="CIRCUIT")
 
-            # Create a temporary JSON file for the circuit (will be cleaned up)
-            import tempfile
+            # Create JSON netlist in project directory (canonical format)
+            json_path = output_path / f"{output_path.name}.json"
+            self.generate_json_netlist(str(json_path))
 
-            with tempfile.NamedTemporaryFile(
-                mode="w", suffix=".json", delete=False
-            ) as temp_file:
-                temp_json_path = temp_file.name
-                self.generate_json_netlist(temp_json_path)
+            context_logger.info(
+                "Generated canonical JSON netlist",
+                component="CIRCUIT",
+                json_path=str(json_path),
+            )
 
-            try:
-                # Create schematic generator that outputs directly to the project directory
-                generator = SchematicGenerator(str(output_path.parent), project_name)
+            # Create schematic generator that outputs directly to the project directory
+            generator = SchematicGenerator(str(output_path.parent), project_name)
 
-                # Generate the complete project using the temporary JSON file
-                # Legacy system handles placement, modern API handles file writing via write_schematic_file
-                result = generator.generate_project(
-                    json_file=temp_json_path,
-                    placement_algorithm=placement_algorithm,  # PCB placement algorithm  
-                    schematic_placement="sequential",  # Use simple sequential for schematic
-                    generate_pcb=generate_pcb,
-                    force_regenerate=force_regenerate,
-                    draw_bounding_boxes=draw_bounding_boxes,
-                    generate_ratsnest=generate_ratsnest,
-                )
-            finally:
-                # Clean up the temporary JSON file
-                import os
-
-                try:
-                    os.unlink(temp_json_path)
-                except OSError:
-                    pass
+            # Generate the complete project using the JSON file
+            # Legacy system handles placement, modern API handles file writing via write_schematic_file
+            result = generator.generate_project(
+                json_file=str(json_path),
+                placement_algorithm=placement_algorithm,  # PCB placement algorithm
+                schematic_placement="sequential",  # Use simple sequential for schematic
+                generate_pcb=generate_pcb,
+                force_regenerate=force_regenerate,
+                draw_bounding_boxes=draw_bounding_boxes,
+                generate_ratsnest=generate_ratsnest,
+            )
 
             if result.get("success", True):  # Default to success if not specified
                 context_logger.info(
@@ -540,6 +726,12 @@ class Circuit:
                     project_name=project_name,
                     output_path=str(output_path),
                 )
+                # Return success result with JSON path
+                return {
+                    "success": True,
+                    "json_path": json_path,
+                    "project_path": output_path,
+                }
             else:
                 error_msg = result.get(
                     "error", "Unknown error occurred during project generation"
@@ -550,18 +742,29 @@ class Circuit:
                     project_name=project_name,
                     error=error_msg,
                 )
-                raise CircuitSynthError(f"KiCad project generation failed: {error_msg}")
+                return {
+                    "success": False,
+                    "error": error_msg,
+                    "json_path": json_path,
+                    "project_path": output_path,
+                }
 
         except ImportError as e:
             error_msg = f"KiCad integration not available: {e}"
             context_logger.error(error_msg, component="CIRCUIT")
-            raise CircuitSynthError(error_msg) from e
+            return {
+                "success": False,
+                "error": error_msg,
+            }
         except Exception as e:
             error_msg = f"Failed to generate KiCad project '{project_name}': {e}"
             context_logger.error(
                 error_msg, component="CIRCUIT", project_name=project_name
             )
-            raise CircuitSynthError(error_msg) from e
+            return {
+                "success": False,
+                "error": error_msg,
+            }
 
     def simulate(self):
         """
