@@ -13,7 +13,7 @@ from dataclasses import dataclass, field
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
 
-from ..kicad.core.types import Point, SchematicPin
+from ..kicad.core import Point, SchematicPin
 from ..kicad.kicad_symbol_parser import parse_kicad_sym_file
 
 logger = logging.getLogger(__name__)
